"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StateProcessor = void 0;
const jsonpath_plus_1 = require("jsonpath-plus");
class StateProcessor {
    static processInputPath(dataJson, inputPath) {
        if (inputPath === null) {
            return '{}';
        }
        const inputJson = dataJson || '{}';
        const result = jsonpath_plus_1.JSONPath({
            path: inputPath === undefined ? '$' : inputPath,
            json: JSON.parse(inputJson),
        });
        if (!result || result.length === 0) {
            throw new Error('');
        }
        return JSON.stringify(result[0]);
    }
    static validateWaitForTokenParameters(parameters) {
        const acceptableParameterProperties = ['FunctionName', 'Payload'];
        if (!parameters.FunctionName) {
            throw new Error(`The field 'FunctionName' is required but was missing`);
        }
        Object.keys(parameters).forEach((key) => {
            if (!acceptableParameterProperties.includes(key)) {
                throw new Error(`The field "${key}" is not supported by Step Functions`);
            }
        });
    }
    static isContextObjectPath(path) {
        return path.startsWith('$$.');
    }
    static isPathKey(path) {
        return path.endsWith('.$');
    }
    static processWaitForTokenParameters(dataJson, parameters) {
        const inputJson = dataJson || '{}';
        this.validateWaitForTokenParameters(parameters);
        if (typeof parameters.Payload !== 'object') {
            return '{}';
        }
        const output = {};
        Object.entries(parameters.Payload).forEach(([key, value]) => {
            if (this.isPathKey(key)) {
                if (typeof value !== 'string') {
                    throw new Error(`The value for the field '${key}' must be a STRING that contains a JSONPath but was an ${typeof value}`);
                }
                const newKey = key.substring(0, key.length - 2);
                if (this.isContextObjectPath(value)) {
                    output[newKey] = value.substring(3);
                }
                else {
                    const result = jsonpath_plus_1.JSONPath({
                        path: value === undefined ? '$' : value,
                        json: JSON.parse(inputJson),
                    });
                    output[newKey] = result[0];
                }
            }
            else {
                output[key] = value;
            }
        });
        return JSON.stringify(output);
    }
    static processResultPath(json, resultPath) {
        const result = jsonpath_plus_1.JSONPath({
            path: resultPath || '$',
            json: JSON.parse(json),
        });
        if (!result || result.length === 0) {
            throw new Error('');
        }
        return JSON.stringify(result[0]);
    }
    static processOutputPath(json, outputPath) {
        const result = jsonpath_plus_1.JSONPath({
            path: outputPath || '$',
            json: JSON.parse(json),
        });
        if (!result || result.length === 0) {
            throw new Error('');
        }
        return JSON.stringify(result[0]);
    }
}
exports.StateProcessor = StateProcessor;
